Handle

Enum Handle 

pub(crate) enum Handle {
Show 32 variants RsaPrivateKey(RsaPrivateKey), RsaPublicKey(RsaPublicKey), P256PrivateKey(SecretKey), P384PrivateKey(SecretKey), P521PrivateKey(SecretKey), P256PublicKey(PublicKey), P384PublicKey(PublicKey), P521PublicKey(PublicKey), Ed25519PrivateKey(Zeroizing<Vec<u8>>), Ed25519PublicKey(Vec<u8>), X25519PrivateKey(StaticSecret), X25519PublicKey(PublicKey), Aes128Key(Key<Aes128>), Aes192Key(Key<Aes192>), Aes256Key(Key<Aes256>), HkdfSecret(Zeroizing<Vec<u8>>), Pbkdf2(Zeroizing<Vec<u8>>), Hmac(Zeroizing<Vec<u8>>), MlKem512PrivateKey(DecapsulationKey<MlKem512>), MlKem768PrivateKey(DecapsulationKey<MlKem768>), MlKem1024PrivateKey(DecapsulationKey<MlKem1024>), MlKem512PublicKey(EncapsulationKey<MlKem512>), MlKem768PublicKey(EncapsulationKey<MlKem768>), MlKem1024PublicKey(EncapsulationKey<MlKem1024>), MlDsa44PrivateKey(SigningKey<MlDsa44>), MlDsa65PrivateKey(SigningKey<MlDsa65>), MlDsa87PrivateKey(SigningKey<MlDsa87>), MlDsa44PublicKey(VerifyingKey<MlDsa44>), MlDsa65PublicKey(VerifyingKey<MlDsa65>), MlDsa87PublicKey(VerifyingKey<MlDsa87>), ChaCha20Poly1305Key(Key), Argon2Password(Zeroizing<Vec<u8>>),
}
The underlying cryptographic data this key represents.

Please make sure the inner types for secret variants implement the zeroize::ZeroizeOnDrop trait, which signifies that the type will call Zeroize::zeroize on Drop to securely erase the secret from memory.

Variants



RsaPrivateKey(RsaPrivateKey)



RsaPublicKey(RsaPublicKey)



P256PrivateKey(SecretKey)



P384PrivateKey(SecretKey)



P521PrivateKey(SecretKey)



P256PublicKey(PublicKey)



P384PublicKey(PublicKey)



P521PublicKey(PublicKey)



Ed25519PrivateKey(Zeroizing<Vec<u8>>)



Ed25519PublicKey(Vec<u8>)



X25519PrivateKey(StaticSecret)



X25519PublicKey(PublicKey)



Aes128Key(Key<Aes128>)



Aes192Key(Key<Aes192>)



Aes256Key(Key<Aes256>)



HkdfSecret(Zeroizing<Vec<u8>>)



Pbkdf2(Zeroizing<Vec<u8>>)



Hmac(Zeroizing<Vec<u8>>)



MlKem512PrivateKey(DecapsulationKey<MlKem512>)



MlKem768PrivateKey(DecapsulationKey<MlKem768>)



MlKem1024PrivateKey(DecapsulationKey<MlKem1024>)



MlKem512PublicKey(EncapsulationKey<MlKem512>)



MlKem768PublicKey(EncapsulationKey<MlKem768>)



MlKem1024PublicKey(EncapsulationKey<MlKem1024>)



MlDsa44PrivateKey(SigningKey<MlDsa44>)



MlDsa65PrivateKey(SigningKey<MlDsa65>)



MlDsa87PrivateKey(SigningKey<MlDsa87>)



MlDsa44PublicKey(VerifyingKey<MlDsa44>)



MlDsa65PublicKey(VerifyingKey<MlDsa65>)



MlDsa87PublicKey(VerifyingKey<MlDsa87>)



ChaCha20Poly1305Key(Key)



Argon2Password(Zeroizing<Vec<u8>>)

Implementations

Source

impl Handle

pub(crate) fn as_bytes(&self) -> &[u8]